@@ -448,7 +448,7 @@ class InvalidDNSNameError(BotoCoreError):
 class InvalidS3AddressingStyleError(BotoCoreError):
     """Error when an invalid path style is specified"""
     fmt = (
-        'S3 addressing style {s3_addressing_style} is invaild. Valid options '
+        'S3 addressing style {s3_addressing_style} is invalid. Valid options '
         'are: \'auto\', \'virtual\', and \'path\''
     )
 
@@ -480,7 +480,15 @@ class InvalidMaxRetryAttemptsError(InvalidRetryConfigurationError):
     """Error when invalid retry configuration is specified"""
     fmt = (
         'Value provided to "max_attempts": {provided_max_attempts} must '
-        'be an integer greater than or equal to zero.'
+        'be an integer greater than or equal to {min_value}.'
+    )
+
+
+class InvalidRetryModeError(InvalidRetryConfigurationError):
+    """Error when invalid retry mode configuration is specified"""
+    fmt = (
+        'Invalid value provided to "mode": "{provided_retry_mode}" must '
+        'be one of: "legacy", "standard", "adaptive"'
     )
 
 
@@ -489,7 +497,7 @@ class InvalidS3UsEast1RegionalEndpointConfigError(BotoCoreError):
     fmt = (
         'S3 us-east-1 regional endpoint option '
         '{s3_us_east_1_regional_endpoint_config} is '
-        'invaild. Valid options are: legacy and regional'
+        'invalid. Valid options are: legacy and regional'
     )
 
 
@@ -497,7 +505,7 @@ class InvalidSTSRegionalEndpointsConfigError(BotoCoreError):
     """Error when invalid sts regional endpoints configuration is specified"""
     fmt = (
         'STS regional endpoints option {sts_regional_endpoints_config} is '
-        'invaild. Valid options are: legacy and regional'
+        'invalid. Valid options are: legacy and regional'
     )
 
 
@@ -549,3 +557,9 @@ class MissingServiceIdError(UndefinedModelAttributeError):
         msg = self.fmt.format(**kwargs)
         Exception.__init__(self, msg)
         self.kwargs = kwargs
+
+
+class CapacityNotAvailableError(BotoCoreError):
+    fmt = (
+        'Insufficient request capacity available.'
+    )
