@@ -18,10 +18,10 @@ from nose.tools import assert_equal
 
 import botocore.session
 from botocore.config import Config
-from botocore.compat import urlsplit
-from botocore.compat import parse_qs
+from botocore.compat import datetime, urlsplit, parse_qs
 from botocore.exceptions import ParamValidationError, ClientError
 from botocore.exceptions import InvalidS3UsEast1RegionalEndpointConfigError
+from botocore.parsers import ResponseParserError
 from botocore import UNSIGNED
 
 
@@ -409,6 +409,63 @@ class TestS3ClientConfigResolution(BaseS3ClientConfigurationTest):
         self.assertEqual(client.meta.region_name, 'aws-global')
 
 
+class TestS3Copy(BaseS3OperationTest):
+
+    def create_s3_client(self, **kwargs):
+        client_kwargs = {
+            'region_name': self.region
+        }
+        client_kwargs.update(kwargs)
+        return self.session.create_client('s3', **client_kwargs)
+
+    def create_stubbed_s3_client(self, **kwargs):
+        client = self.create_s3_client(**kwargs)
+        http_stubber = ClientHTTPStubber(client)
+        http_stubber.start()
+        return client, http_stubber
+
+    def test_s3_copy_object_with_empty_response(self):
+        self.client, self.http_stubber = self.create_stubbed_s3_client(
+            region_name='us-east-1'
+        )
+
+        empty_body = b''
+        complete_body = (
+            b'<?xml version="1.0" encoding="UTF-8"?>\n\n'
+            b'<CopyObjectResult '
+            b'xmlns="http://s3.amazonaws.com/doc/2006-03-01/">'
+            b'<LastModified>2020-04-21T21:03:31.000Z</LastModified>'
+            b'<ETag>&quot;s0mEcH3cK5uM&quot;</ETag></CopyObjectResult>'
+        )
+
+        self.http_stubber.add_response(status=200, body=empty_body)
+        self.http_stubber.add_response(status=200, body=complete_body)
+        response = self.client.copy_object(
+            Bucket='bucket',
+            CopySource='other-bucket/test.txt',
+            Key='test.txt',
+        )
+
+        # Validate we retried and got second body
+        self.assertEquals(len(self.http_stubber.requests), 2)
+        self.assertEquals(response['ResponseMetadata']['HTTPStatusCode'], 200)
+        self.assertTrue('CopyObjectResult' in response)
+
+    def test_s3_copy_object_with_incomplete_response(self):
+        self.client, self.http_stubber = self.create_stubbed_s3_client(
+            region_name='us-east-1'
+        )
+
+        incomplete_body = b'<?xml version="1.0" encoding="UTF-8"?>\n\n\n'
+        self.http_stubber.add_response(status=200, body=incomplete_body)
+        with self.assertRaises(ResponseParserError):
+            self.client.copy_object(
+                Bucket='bucket',
+                CopySource='other-bucket/test.txt',
+                Key='test.txt',
+            )
+
+
 class TestAccesspointArn(BaseS3ClientConfigurationTest):
     _V4_AUTH_REGEX = re.compile(
         r'AWS4-HMAC-SHA256 '
@@ -1192,6 +1249,10 @@ def test_correct_url_used_for_s3():
         s3_config=virtual_hosting,
         customer_provided_endpoint='https://foo.amazonaws.com',
         expected_url='https://bucket.foo.amazonaws.com/key')
+    yield t.case(
+        region='unknown', bucket='bucket', key='key',
+        s3_config=virtual_hosting,
+        expected_url='https://bucket.s3.unknown.amazonaws.com/key')
 
     # Test us-gov with virtual addressing.
     yield t.case(
@@ -1220,6 +1281,10 @@ def test_correct_url_used_for_s3():
         s3_config=path_style,
         customer_provided_endpoint='https://foo.amazonaws.com/',
         expected_url='https://foo.amazonaws.com/bucket/key')
+    yield t.case(
+        region='unknown', bucket='bucket', key='key',
+        s3_config=path_style,
+        expected_url='https://s3.unknown.amazonaws.com/bucket/key')
 
     # S3 accelerate
     use_accelerate = {'use_accelerate_endpoint': True}
@@ -1261,6 +1326,10 @@ def test_correct_url_used_for_s3():
         # Extra components must be whitelisted.
         customer_provided_endpoint='https://s3-accelerate.foo.amazonaws.com',
         expected_url='https://s3-accelerate.foo.amazonaws.com/bucket/key')
+    yield t.case(
+        region='unknown', bucket='bucket', key='key',
+        s3_config=use_accelerate,
+        expected_url='https://bucket.s3-accelerate.amazonaws.com/key')
     # Use virtual even if path is specified for s3 accelerate because
     # path style will not work with S3 accelerate.
     yield t.case(
@@ -1303,6 +1372,10 @@ def test_correct_url_used_for_s3():
         region='us-west-2', bucket='bucket', key='key',
         s3_config=use_dualstack, signature_version='s3v4',
         expected_url='https://bucket.s3.dualstack.us-west-2.amazonaws.com/key')
+    yield t.case(
+        region='unknown', bucket='bucket', key='key',
+        s3_config=use_dualstack, signature_version='s3v4',
+        expected_url='https://bucket.s3.dualstack.unknown.amazonaws.com/key')
     # Non DNS compatible buckets use path style for dual stack.
     yield t.case(
         region='us-west-2', bucket='bucket.dot', key='key',
@@ -1485,6 +1558,14 @@ def test_correct_url_used_for_s3():
             'unknown.amazonaws.com/key'
         )
     )
+    yield t.case(
+        region='unknown', bucket=accesspoint_arn, key='key',
+        s3_config={'use_arn_region': True},
+        expected_url=(
+            'https://myendpoint-123456789012.s3-accesspoint.'
+            'us-west-2.amazonaws.com/key'
+        )
+    )
     accesspoint_arn_cn = (
         'arn:aws-cn:s3:cn-north-1:123456789012:accesspoint:myendpoint'
     )
@@ -1624,6 +1705,11 @@ def test_correct_url_used_for_s3():
         s3_config=us_east_1_regional_endpoint,
         expected_url=(
             'https://bucket.s3.amazonaws.com/key'))
+    yield t.case(
+        region='unknown', bucket='bucket', key='key',
+        s3_config=us_east_1_regional_endpoint,
+        expected_url=(
+            'https://bucket.s3.unknown.amazonaws.com/key'))
     yield t.case(
         region='us-east-1', bucket='bucket', key='key',
         s3_config={
@@ -1666,6 +1752,12 @@ def test_correct_url_used_for_s3():
         expected_url=(
             'https://bucket.s3.amazonaws.com/key'))
 
+    yield t.case(
+        region='unknown', bucket='bucket', key='key',
+        s3_config=us_east_1_regional_endpoint_legacy,
+        expected_url=(
+            'https://bucket.s3.unknown.amazonaws.com/key'))
+
 
 class S3AddressingCases(object):
     def __init__(self, verify_function):
