@@ -552,59 +552,6 @@ class TestHandlers(BaseSessionTest):
                   'UserData': b64_user_data}
         self.assertEqual(params, result)
 
-    def test_register_retry_for_handlers_with_no_metadata(self):
-        no_endpoint_prefix = {'metadata': {}}
-        session = mock.Mock()
-        handlers.register_retries_for_service(service_data=no_endpoint_prefix,
-                                              session=mock.Mock(),
-                                              service_name='foo')
-        self.assertFalse(session.register.called)
-
-    def test_register_retry_for_handlers_with_no_service_id(self):
-        service_data = {
-            'metadata': {
-                'endpointPrefix': 'foo',
-            },
-        }
-        session = mock.Mock(spec=Session)
-        loader = mock.Mock(spec=Loader)
-        session.get_component.return_value = loader
-        service_name = 'foo'
-        with self.assertRaisesRegexp(MissingServiceIdError, service_name):
-            handlers.register_retries_for_service(
-                service_data=service_data,
-                session=session,
-                service_name=service_name,
-            )
-
-    def test_register_retry_handlers(self):
-        service_data = {
-            'metadata': {
-                'endpointPrefix': 'foo',
-                'serviceId': 'foo',
-            },
-        }
-        session = mock.Mock()
-        loader = mock.Mock()
-        session.get_component.return_value = loader
-        loader.load_data.return_value = {
-            'retry': {
-                '__default__': {
-                    'max_attempts': 10,
-                    'delay': {
-                        'type': 'exponential',
-                        'base': 2,
-                        'growth_factor': 5,
-                    },
-                },
-            },
-        }
-        handlers.register_retries_for_service(service_data=service_data,
-                                              session=session,
-                                              service_name='foo')
-        session.register.assert_called_with('needs-retry.foo', mock.ANY,
-                                            unique_id='retry-config-foo')
-
     def test_get_template_has_error_response(self):
         original = {'Error': {'Code': 'Message'}}
         handler_input = copy.deepcopy(original)
@@ -807,6 +754,23 @@ class TestHandlers(BaseSessionTest):
     def test_validation_is_noop_if_no_bucket_param_exists(self):
         self.assertIsNone(handlers.validate_bucket_name(params={}))
 
+    def test_validation_is_s3_accesspoint_arn(self):
+        try:
+            arn = 'arn:aws:s3:us-west-2:123456789012:accesspoint:endpoint'
+            handlers.validate_bucket_name({'Bucket': arn})
+        except ParamValidationError:
+            self.fail('The s3 arn: %s should pass validation' % arn)
+
+    def test_validation_is_global_s3_bucket_arn(self):
+        with self.assertRaises(ParamValidationError):
+            arn = 'arn:aws:s3:::mybucket'
+            handlers.validate_bucket_name({'Bucket': arn})
+
+    def test_validation_is_other_service_arn(self):
+        with self.assertRaises(ParamValidationError):
+            arn = 'arn:aws:ec2:us-west-2:123456789012:instance:myinstance'
+            handlers.validate_bucket_name({'Bucket': arn})
+
     def test_validate_non_ascii_metadata_values(self):
         with self.assertRaises(ParamValidationError):
             handlers.validate_ascii_metadata({'Metadata': {'foo': u'\u2713'}})
@@ -957,13 +921,6 @@ class TestHandlers(BaseSessionTest):
         self.assertEqual(parsed['CommonPrefixes'][0]['Prefix'],
                          u'\xe7\xf6s% asd\x08 c')
 
-    def test_get_bucket_location_optional(self):
-        # This handler should no-op if another hook (i.e. stubber) has already
-        # filled in response
-        response = {"LocationConstraint": "eu-west-1"}
-        handlers.parse_get_bucket_location(response, None),
-        self.assertEqual(response["LocationConstraint"], "eu-west-1")
-
     def test_set_operation_specific_signer_no_auth_type(self):
         signing_name = 'myservice'
         context = {'auth_type': None}
@@ -1054,10 +1011,12 @@ class TestRetryHandlerOrder(BaseSessionTest):
         return names
 
     def test_s3_special_case_is_before_other_retry(self):
+        client = self.session.create_client('s3')
         service_model = self.session.get_service_model('s3')
         operation = service_model.operation_model('CopyObject')
-        responses = self.session.emit(
+        responses = client.meta.events.emit(
             'needs-retry.s3.CopyObject',
+            request_dict={},
             response=(mock.Mock(), mock.Mock()), endpoint=mock.Mock(),
             operation=operation, attempts=1, caught_exception=None)
         # This is implementation specific, but we're trying to verify that
@@ -1383,3 +1342,13 @@ class TestPrependToHost(unittest.TestCase):
         prepended = self._prepend_to_host(
             'https://bar.baz.example.com/path', 'foo')
         self.assertEqual(prepended, 'https://foo.bar.baz.example.com/path')
+
+    def test_does_validate_long_host(self):
+        with self.assertRaises(ParamValidationError):
+           self._prepend_to_host(
+               'https://example.com/path', 'toolong'*100)
+
+    def test_does_validate_host_with_illegal_char(self):
+        with self.assertRaises(ParamValidationError):
+           self._prepend_to_host(
+               'https://example.com/path', 'host#name')
